@@ -1,5 +1,5 @@
 name = 'sour-cereal'
-version = '1.0'
+version = '1.0.1'
 
 author = 'Carlos Alberto Duarte Pinto'
 author_email = 'carlos.adpinto@gmail.com'
@@ -9,7 +9,9 @@ keywords = ['abstraction', 'data extraction', 'data sources', 'interface',
 
 description = 'An abstraction of data source for extraction applications usage'
 
-url = 'https://github.com/CarlosAdp/sour-cereal/archive/v1.0.tar.gz'
+url = 'https://github.com/CarlosAdp/sour-cereal'
+
+download_url = 'https://github.com/CarlosAdp/sour-cereal/archive/v1.0.tar.gz'
 
 classifiers = [
     'Programming Language :: Python :: 3.6',
